common_listview library
Classes
- CommonPaginatedList
- loading when true, shows a circular loading indicator. page current page. onNext function is called when the user scrolls to the bottom of the list. length number of items in the list. onRefresh function is called when the user pulls to refresh the list. itemBuilder function that builds the list item.