CommonPaginatedList class
loading when true, shows a circular loading indicator. page current page. onNext function is called when the user scrolls to the bottom of the list. length number of items in the list. onRefresh function is called when the user pulls to refresh the list. itemBuilder function that builds the list item.
errorMsg error message to show when the list fails to load. Commonly used when the list is empty.
height height of the divider padding padding of the list
separator divider Widget between list items. Default is a Divider. If you want to change the default Divider to be your own, use this parameter. loadingPlaceholder widget to show when the list is loading. scrollController controller for the list view. physics physics for the list view.
placeholderTextStyle style for the error message and no data message. emptyPlaceHolder widget to show when the list is empty.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CommonPaginatedList
Constructors
-
CommonPaginatedList({Key? key, required bool loading, required int page, required int length, required Widget itemBuilder(BuildContext c, int i), required Function onNext, required Future<
void> onRefresh(), double? height, EdgeInsets? padding, required String? errorMsg, Widget? emptyPlaceHolder, Axis scrollDirection = Axis.vertical, Widget? separator, Widget? loadingPlaceholder, ScrollController? scrollController, ScrollPhysics? physics, TextStyle? placeholderTextStyle}) -
const
Properties
- emptyPlaceHolder → Widget?
-
final
- errorMsg → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- itemBuilder → Widget Function(BuildContext c, int i)
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- length → int
-
final
- loading → bool
-
final
- loadingPlaceholder → Widget?
-
final
- onNext → Function
-
final
-
onRefresh
→ Future<
void> Function() -
final
- padding → EdgeInsets?
-
final
- page → int
-
final
- physics → ScrollPhysics?
-
final
- placeholderTextStyle → TextStyle?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController?
-
final
- scrollDirection → Axis
-
final
- separator → Widget?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited